import "./tasks/PON.wdl" as PON
import "./tasks/bcftools.wdl" as bcftools
import "./tasks/TNseq.wdl" as TNseq
import "./tasks/TNscope.wdl" as TNscope
import "./tasks/annovar.wdl" as annovar
import "./tasks/vcf2maf.wdl" as vcf2maf


workflow {{ project_name }} {

	File normal_recaled_bam
	File normal_recaled_bam_index
	File corealigner_bam
	File corealigner_bam_index

	String SENTIEON_INSTALL_DIR
	String SENTIEON_LICENSE
	String sample
	String sentieon_docker
	String annovar_docker
	String vcf2maf_r_docker
	String bcftools_docker
	
	File ref_dir
	String fasta
	File dbmills_dir
	String db_mills
	File dbsnp_dir
	String dbsnp
	File regions
	File database
	String disk_size
	String cluster_config

	Boolean PONmode
	File? cosmic_dir
	String? cosmic_vcf

	Boolean set_annovar
	Boolean set_vcf2maf


	if (PONmode) {
		call PON.PON as PON {
			input:
			SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
			SENTIEON_LICENSE=SENTIEON_LICENSE,
			sample=sample,
			fasta=fasta,
			ref_dir=ref_dir,
			normal_recaled_bam=normal_recaled_bam,
			normal_recaled_bam_index=normal_recaled_bam_index,
			cosmic_vcf=cosmic_vcf,
			cosmic_dir=cosmic_dir,
			dbsnp=dbsnp,
			dbsnp_dir=dbsnp_dir,
			docker=sentieon_docker,
			disk_size=disk_size,
			cluster_config=cluster_config
		}
		call bcftools.bcftools as bcftools {
			input:
			pon_vcf=PON.pon_vcf,
			docker=bcftools_docker,
			disk_size=disk_size,
			cluster_config=cluster_config
		}
	}


	call TNseq.TNseq as TNseq {
		input:
		SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
		SENTIEON_LICENSE=SENTIEON_LICENSE,
		PONmode=PONmode,
		fasta=fasta,
		ref_dir=ref_dir,
		corealigner_bam=corealigner_bam,
		corealigner_bam_index=corealigner_bam_index,
		dbsnp=dbsnp,
		dbsnp_dir=dbsnp_dir,
		tumor_name=sample + "tumor",
		normal_name=sample + "normal",
		cosmic_vcf=cosmic_vcf,
		cosmic_dir=cosmic_dir,
		panel_of_normal_vcf = bcftools.panel_of_normal_vcf,
		docker=sentieon_docker,
		sample=sample,
		disk_size=disk_size,
		cluster_config=cluster_config
	}
    
	call TNscope.TNscope as TNscope {
		input:
		SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
		SENTIEON_LICENSE=SENTIEON_LICENSE,
		PONmode=PONmode,
		fasta=fasta,
		ref_dir=ref_dir,
		corealigner_bam=corealigner_bam,
		corealigner_bam_index=corealigner_bam_index,
		dbsnp=dbsnp,
		dbsnp_dir=dbsnp_dir,
		tumor_name=sample + "tumor",
		normal_name=sample + "normal",
		cosmic_vcf=cosmic_vcf,
		cosmic_dir=cosmic_dir,
		panel_of_normal_vcf = bcftools.panel_of_normal_vcf,
		docker=sentieon_docker,
		sample=sample,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	if (set_annovar){
		call annovar.annovar as annovar {
			input:
			docker=annovar_docker,
			database=database,
			tnscope_vcf_file=TNscope.TNscope_vcf,
			tnseq_vcf_file=TNseq.TNseq_vcf,
			sample=sample,
			cluster_config=cluster_config,
			disk_size=disk_size
		}
	}
	
	if (set_vcf2maf){
		call vcf2maf.vcf2maf as vcf2maf {
			input:
			docker=vcf2maf_r_docker,
			multianno_tnscope_txt=annovar.multianno_tnscope_txt,
			multianno_tnseq_txt=annovar.multianno_tnseq_txt,
			sample=sample,
			cluster_config=cluster_config,
			disk_size=disk_size
		}
	}
}